# Mosqlimate client

[![ci](https://github.com/Mosqlimate-project/mosqlimate-client/workflows/ci/badge.svg)](https://github.com/Mosqlimate-project/mosqlimate-client/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://api.mosqlimate.org/docs/)
[![pypi version](https://img.shields.io/pypi/v/mosqlimate-client.svg)](https://pypi.org/project/mosqlient)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://gitter.im/mosqlimate-client/community)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

client library for the Mosqlimate project data platform.

## Requirements

Mosqlimate client requires Python 3.10 or above.



## Installation

```bash
pip install mosqlient
```

## Using from R
Despite `mosqlient` being a Python library, it can be used from R using the `reticulate` package. Here is an example of how to use `mosqlient` from R:

In the examples folder, you can find an [R jupyter notebook](/examples/Using%20Mosqlient%20from%20R.ipynb) of how to use `mosqlient` from R.
